@@ -5,11 +5,10 @@ import numpy as np
 import requests
 from bs4 import BeautifulSoup
 
-# http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-0222.XM
-
+# http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-0222.XML
 
 def hmrc_to_dataframe(month, year):
-    url = f"http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-{month}{year[-2:]}.XML"
+    url = f"http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-{month}{year[2:]}.XML"
     document = requests.get(url)
     soup = BeautifulSoup(document.content, "xml")
     countryName = soup.find_all('countryName')
@@ -31,5 +30,5 @@ def hmrc_to_dataframe(month, year):
                                     'countryName', 'countryCode', 'currencyName', 'currencyCode', 'rateNew'])
     exchange_rate_df['reported_month_year'] = url[-8:-4]
     exchange_rate_df['exchageRate_starDate'] = pd.to_datetime(
-        exchange_rate_df['reported_month_year'], format="%m-%Y")
-    return exchange_rate_df
+        exchange_rate_df['reported_month_year'], format="%m%y")
+    return exchange_rate_df
\ No newline at end of file
